/*
 * options.c - Handle options from the command line or configuration file.
 *
 * Copyright (C) 2003,2004, 2006, 2007 Brailcom, o.p.s.
 * Copyright (C) 2010 OpenTTS developers
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this package; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#include "config.h"

#include <assert.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "log.h"
#include "options.h"

struct ospeakup_options options;

void set_int_option(struct int_option *i, int value, enum source source)
{
	assert(i);
	i->value = value;
	i->source = source;
}

void set_string_option(struct string_option *s, char *value, enum source source)
{
	char *tmp;

	assert(s);
	assert(value);
	tmp = strdup(value);
	if (tmp == NULL)
		FATAL(-1, "Out of memory, unable to continue!\n");
	if ((s->value != NULL) && (source != DEFAULT_SETTING))
		free(s->value);
	s->value = tmp;
	s->source = source;
}

void set_default_options(void)
{
	set_string_option(&options.config_file_name, SYS_CONF "/ospeakup.conf",
			  DEFAULT_SETTING);
	set_int_option(&options.dont_init_tables, 0, DEFAULT_SETTING);
	set_string_option(&options.language, "en", DEFAULT_SETTING);
	set_int_option(&options.probe_mode, 0, DEFAULT_SETTING);
	set_int_option(&options.spd_spk_mode, MODE_DAEMON, DEFAULT_SETTING);
	set_int_option(&options.log_level, 3, DEFAULT_SETTING);
	set_string_option(&options.log_path, "/var/log", DEFAULT_SETTING);
	set_string_option(&options.speakup_characters,
			  "/sys/accessibility/speakup/i18n/characters",
			  DEFAULT_SETTING);
	set_string_option(&options.speakup_chartab,
			  "/sys/accessibility/speakup/i18n/chartab",
			  DEFAULT_SETTING);
	set_string_option(&options.speakup_coding, "iso-8859-1",
			  DEFAULT_SETTING);
	set_string_option(&options.speakup_device, "/dev/softsynth",
			  DEFAULT_SETTING);
}
