/*
 * options.h - Defines possible command line options
 *
 * Copyright (C) 2003, 2006 Brailcom, o.p.s.
 * Copyright (C) 2010 OpenTTS developers
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this package; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef OPTIONS_H
#define OPTIONS_H

#define MODE_DAEMON 1
#define MODE_SINGLE 0

enum source {
	DEFAULT_SETTING,
	COMMAND_LINE,
	CONFIG_FILE,
};

struct int_option {
	int value;
	enum source source;
};

struct string_option {
	char *value;
	enum source source;
};

struct ospeakup_options {
	struct string_option config_file_name;
	struct int_option dont_init_tables;
	struct string_option language;
	struct string_option log_path;
	struct int_option log_level;
	struct int_option probe_mode;
	struct int_option spd_spk_mode;
	struct string_option speakup_characters;
	struct string_option speakup_chartab;
	struct string_option speakup_coding;
	struct string_option speakup_device;
};

extern struct ospeakup_options options;

void set_int_option(struct int_option *i, int value, enum source source);
void set_string_option(struct string_option *s, char *value,
		       enum source source);
void set_default_options(void);

#endif
